@@ -89,14 +89,14 @@ static char *const *parse_plugin(const char *plugin, const char *host, const cha
 	char *cp, *plugin_copy;
 	unsigned int plugin_copy_len;
 	unsigned int plugin_offset = 0, plugin_copy_offset = 0;
-	unsigned int i, s = 2 * sizeof(char*), host_count = 0, service_count = 0;
+	unsigned int i, vecsiz = 2 * sizeof(char*), host_count = 0, service_count = 0;
 	unsigned int plugin_len = strlen(plugin);
 	unsigned int host_len = strlen(host);
 	unsigned int service_len = strlen(service);
 
 	for (c = p = plugin; *c; c++)
 	{	if (isspace((unsigned char)*c) && !isspace((unsigned char)*p))
-			s += sizeof(char*);
+			vecsiz += sizeof(char*);
 		if (*p == '%' && *c == 'h')
 			host_count++;
 		if (*p == '%' && *c == 'p')
@@ -104,7 +104,8 @@ static char *const *parse_plugin(const char *plugin, const char *host, const cha
 		p = c;
 	}
 
-	plugin_copy_len = plugin_len + host_len * host_count + service_len * service_count;
+	/* we need to discount 2 bytes for each placeholder */
+	plugin_copy_len = plugin_len + (host_len - 2) * host_count + (service_len - 2) * service_count;
 	plugin_copy = (char *)malloc(plugin_copy_len + 1);
 	if (!plugin_copy)
 	{
@@ -129,18 +130,18 @@ static char *const *parse_plugin(const char *plugin, const char *host, const cha
 			plugin_copy_offset++;
 		}
 	}
-	plugin_copy[plugin_copy_len] = 0;
+	plugin_copy[plugin_copy_offset] = 0;
 
 	/* XXX FIXME - is this perhaps a bit too simplistic to chop down the argument strings without any respect to quoting?
 	 * better write a generic function that tracks arguments instead... */
-	argvec = (char **)malloc(s);
+	argvec = (char **)malloc(vecsiz);
 	if (!argvec)
 	{
 		free(plugin_copy);
 		report(stderr, GT_("fetchmail: malloc failed\n"));
 		return NULL;
 	}
-	memset(argvec, 0, s);
+	memset(argvec, 0, vecsiz);
 	for (p = cp = plugin_copy, i = 0; *cp; cp++)
 	{	if ((!isspace((unsigned char)*cp)) && (cp == p ? 1 : isspace((unsigned char)*p))) {
 			argvec[i] = cp;
@@ -392,6 +393,10 @@ va_dcl {
 #pragma message "WARNING - LibreSSL is unsupported. Use at your own risk."
 #endif
 
+#if OPENSSL_VERSION_NUMBER < 0x1010100fL
+#pragma message "WARNING - OpenSSL SHOULD be at least version 1.1.1."
+#endif
+
 #if OPENSSL_VERSION_NUMBER < fm_MIN_OPENSSL_VER
 #error Your OpenSSL version must be at least 1.0.2 release. Older OpenSSL versions are unsupported.
 #else
@@ -839,7 +844,8 @@ static int SSL_verify_callback(int ok_return, X509_STORE_CTX *ctx, int strict)
 			report(stderr, GT_(	"This could mean that the root CA's signing certificate is not in the "
 						"trusted CA certificate location, or that c_rehash needs to be run "
 						"on the certificate directory. For details, please "
-						"see the documentation of --sslcertpath and --sslcertfile in the manual page.\n"));
+						"see the documentation of --sslcertpath and --sslcertfile in the manual page. "
+						"See README.SSL for details.\n"));
 			break;
 		default:
 			break;
